@@ -1,11 +1,11 @@
 package Mongoose::Meta::AttributeTraits;
 BEGIN {
-  $Mongoose::Meta::AttributeTraits::VERSION = '0.07';
+  $Mongoose::Meta::AttributeTraits::VERSION = '0.08';
 }
 
 package Mongoose::Meta::Attribute::Trait::Binary;
 BEGIN {
-  $Mongoose::Meta::Attribute::Trait::Binary::VERSION = '0.07';
+  $Mongoose::Meta::Attribute::Trait::Binary::VERSION = '0.08';
 }
 use strict;
 use Moose::Role;
@@ -26,16 +26,16 @@ has 'lazy_select' => (
 {
 	package Moose::Meta::Attribute::Custom::Trait::Binary;
 BEGIN {
-  $Moose::Meta::Attribute::Custom::Trait::Binary::VERSION = '0.07';
+  $Moose::Meta::Attribute::Custom::Trait::Binary::VERSION = '0.08';
 }
 	sub register_implementation {'Mongoose::Meta::Attribute::Trait::Binary'}
 }
 
 # -----------------------------------------------------------------
 
-package Mongoose::Meta::Attribute::Trait::DoNotSerialize;
+package Mongoose::Meta::Attribute::Trait::DoNotMongoSerialize;
 BEGIN {
-  $Mongoose::Meta::Attribute::Trait::DoNotSerialize::VERSION = '0.07';
+  $Mongoose::Meta::Attribute::Trait::DoNotMongoSerialize::VERSION = '0.08';
 }
 use strict;
 use Moose::Role;
@@ -54,11 +54,11 @@ has 'lazy_select' => (
 # -----------------------------------------------------------------
 
 {
-	package Moose::Meta::Attribute::Custom::Trait::DoNotSerialize;
+	package Moose::Meta::Attribute::Custom::Trait::DoNotMongoSerialize;
 BEGIN {
-  $Moose::Meta::Attribute::Custom::Trait::DoNotSerialize::VERSION = '0.07';
+  $Moose::Meta::Attribute::Custom::Trait::DoNotMongoSerialize::VERSION = '0.08';
 }
-	sub register_implementation {'Mongoose::Meta::Attribute::Trait::DoNotSerialize'}
+	sub register_implementation {'Mongoose::Meta::Attribute::Trait::DoNotMongoSerialize'}
 }
 
 # -----------------------------------------------------------------
@@ -66,7 +66,7 @@ BEGIN {
 {
 	package Mongoose::Meta::Attribute::Trait::Raw;
 BEGIN {
-  $Mongoose::Meta::Attribute::Trait::Raw::VERSION = '0.07';
+  $Mongoose::Meta::Attribute::Trait::Raw::VERSION = '0.08';
 }
 	use strict;
 	use Moose::Role;
@@ -74,12 +74,12 @@ BEGIN {
 {
 	package Moose::Meta::Attribute::Custom::Trait::Raw;
 BEGIN {
-  $Moose::Meta::Attribute::Custom::Trait::Raw::VERSION = '0.07';
+  $Moose::Meta::Attribute::Custom::Trait::Raw::VERSION = '0.08';
 }
 	sub register_implementation {'Mongoose::Meta::Attribute::Trait::Raw'}
 }
 
-#package Moose::Meta::Attribute::Custom::DoNotSerialize;
+#package Moose::Meta::Attribute::Custom::DoNotMongoSerialize;
 #use Moose::Role;
 
 #package Moose::Meta::Attribute::Custom::Trait::PrimaryKey;
@@ -91,13 +91,13 @@ Mongoose::Meta::AttributeTraits - Mongoose related attribute traits
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 DESCRIPTION
 
 All Moose attribute traits used by Mongoose are defined here.
 
-=head2 DoNotSerialize
+=head2 DoNotMongoSerialize
 
 Makes Mongoose skip collapsing or expanding the attribute.
 
